@@ -5,6 +5,18 @@ import argparse
 import glob
 import subprocess
 import re
+import platform
+
+
+def patch_distutils_cfg():
+    if platform.system() == 'Darwin':
+        if not os.path.exists(os.path.expanduser("~/.pydistutils.cfg")):
+            print "WARNING: Homebrew python on OS X has a goofy bug where distribute/pip fails to install things with prefixes. I can fix this by creating a ~/.pydistutils.cfg file for you. You can always delete this after running."
+            if raw_input("Do you want me to create ~/.pydistutils.cfg for you? (y/N): ") in ('Y', 'y', 'yes', 'cool'):
+                with open(os.path.expanduser("~/.pydistutils.cfg"), 'w') as f:
+                    f.write('[install]\nprefix=')
+            else:
+                raise ValueError("Can not continue :/")
 
 
 def read_requirements(reqfile):
@@ -84,6 +96,7 @@ def main():
     parser.add_argument('--pre', help="allow pre-release versions", action='store_true')
     args = parser.parse_args()
 
+    patch_distutils_cfg()
     clean_destination(args.target)
     requirements = read_requirements(args.requirements)
     install_packages(requirements, args.target, args.pre)
